# Generated by roxygen2: do not edit by hand

S3method(print,goose_cache_stats)
S3method(print,goose_code_review)
S3method(print,goose_error_explanation)
S3method(print,goose_palette)
S3method(print,goose_response)
S3method(print,goose_session)
S3method(print,goose_template)
export("%>%")
export(StreamHandler)
export(StreamSession)
export(WorkerPool)
export(brand_css)
export(brand_css_inline)
export(brand_palette)
export(brand_rmd_template)
export(format_ai_response)
export(format_conversation)
export(goose_addin_chat)
export(goose_addin_quick)
export(goose_addin_review)
export(goose_addin_snippet)
export(goose_addin_template)
export(goose_ask)
export(goose_ask_raw)
export(goose_async)
export(goose_async_retry)
export(goose_async_timeout)
export(goose_backup)
export(goose_batch)
export(goose_batch_file)
export(goose_cache_clear)
export(goose_cache_export)
export(goose_cache_get)
export(goose_cache_import)
export(goose_cache_init)
export(goose_cache_set)
export(goose_cache_stats)
export(goose_cache_ui)
export(goose_cache_warmup)
export(goose_cached)
export(goose_check_installation)
export(goose_clean_text)
export(goose_clear_all)
export(goose_clear_category)
export(goose_clear_tags)
export(goose_configure)
export(goose_continuation_prompt)
export(goose_conversation_ui)
export(goose_create_brand)
export(goose_create_brand_ai)
export(goose_create_quarto)
export(goose_create_report)
export(goose_create_template)
export(goose_delete)
export(goose_divider)
export(goose_document)
export(goose_exists)
export(goose_explain_error)
export(goose_format_options)
export(goose_generate_tests)
export(goose_get_config)
export(goose_give_sample)
export(goose_honk)
export(goose_insert_chunk)
export(goose_list)
export(goose_load)
export(goose_loop_me)
export(goose_make_a_plan)
export(goose_map)
export(goose_mapreduce)
export(goose_optimize_palette)
export(goose_optimize_plot)
export(goose_pipeline)
export(goose_quarto_chunk)
export(goose_query)
export(goose_recipe)
export(goose_reduce)
export(goose_rename)
export(goose_rename_columns)
export(goose_review_code)
export(goose_rmd_ai)
export(goose_save)
export(goose_session)
export(goose_session_clear)
export(goose_session_end)
export(goose_session_list)
export(goose_session_save)
export(goose_session_start)
export(goose_stream)
export(goose_stream_async)
export(goose_stream_multi)
export(goose_stream_session)
export(goose_suggest_colors)
export(goose_template)
export(goose_template_apply)
export(goose_template_builtin)
export(goose_template_from_query)
export(goose_template_list)
export(goose_template_load)
export(goose_template_save)
export(goose_template_validate)
export(goose_test_cli)
export(goose_version)
export(goose_view_column_map)
export(goose_worker_pool)
export(load_brand)
export(preview_brand)
export(register_goose_engine)
export(theme_brand)
export(validate_brand)
export(with_goose_session)
import(ggplot2)
import(graphics)
import(miniUI)
import(shiny)
import(yaml)
importFrom(DBI,dbConnect)
importFrom(DBI,dbDisconnect)
importFrom(DBI,dbExecute)
importFrom(DBI,dbGetQuery)
importFrom(R6,R6Class)
importFrom(digest,digest)
importFrom(future,future)
importFrom(future,multisession)
importFrom(future,plan)
importFrom(future,sequential)
importFrom(future.apply,future_lapply)
importFrom(glue,glue)
importFrom(grDevices,col2rgb)
importFrom(grDevices,rgb)
importFrom(graphics,hist)
importFrom(graphics,par)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,read_json)
importFrom(jsonlite,toJSON)
importFrom(jsonlite,write_json)
importFrom(knitr,knit_engines)
importFrom(later,later)
importFrom(magrittr,"%>%")
importFrom(miniUI,gadgetTitleBar)
importFrom(miniUI,miniButtonBlock)
importFrom(miniUI,miniContentPanel)
importFrom(miniUI,miniPage)
importFrom(miniUI,miniTitleBarButton)
importFrom(processx,process)
importFrom(promises,as.promise)
importFrom(promises,promise)
importFrom(promises,promise_race)
importFrom(rappdirs,user_cache_dir)
importFrom(rappdirs,user_data_dir)
importFrom(rstudioapi,documentNew)
importFrom(rstudioapi,documentSave)
importFrom(rstudioapi,getActiveDocumentContext)
importFrom(rstudioapi,getSourceEditorContext)
importFrom(rstudioapi,insertText)
importFrom(shiny,HTML)
importFrom(shiny,actionButton)
importFrom(shiny,br)
importFrom(shiny,column)
importFrom(shiny,dataTableOutput)
importFrom(shiny,dialogViewer)
importFrom(shiny,div)
importFrom(shiny,downloadButton)
importFrom(shiny,downloadHandler)
importFrom(shiny,fluidPage)
importFrom(shiny,fluidRow)
importFrom(shiny,h3)
importFrom(shiny,h4)
importFrom(shiny,hr)
importFrom(shiny,icon)
importFrom(shiny,insertUI)
importFrom(shiny,mainPanel)
importFrom(shiny,modalButton)
importFrom(shiny,modalDialog)
importFrom(shiny,numericInput)
importFrom(shiny,observe)
importFrom(shiny,observeEvent)
importFrom(shiny,p)
importFrom(shiny,plotOutput)
importFrom(shiny,reactive)
importFrom(shiny,reactiveVal)
importFrom(shiny,reactiveValues)
importFrom(shiny,removeNotification)
importFrom(shiny,removeUI)
importFrom(shiny,renderDataTable)
importFrom(shiny,renderPlot)
importFrom(shiny,renderPrint)
importFrom(shiny,renderText)
importFrom(shiny,renderUI)
importFrom(shiny,req)
importFrom(shiny,runGadget)
importFrom(shiny,selectInput)
importFrom(shiny,setProgress)
importFrom(shiny,shinyApp)
importFrom(shiny,showNotification)
importFrom(shiny,sidebarLayout)
importFrom(shiny,sidebarPanel)
importFrom(shiny,span)
importFrom(shiny,stopApp)
importFrom(shiny,tabPanel)
importFrom(shiny,tabsetPanel)
importFrom(shiny,tagList)
importFrom(shiny,tags)
importFrom(shiny,textAreaInput)
importFrom(shiny,textInput)
importFrom(shiny,titlePanel)
importFrom(shiny,uiOutput)
importFrom(shiny,updateSelectInput)
importFrom(shiny,updateTextAreaInput)
importFrom(shiny,updateTextInput)
importFrom(shiny,verbatimTextOutput)
importFrom(shiny,withProgress)
importFrom(stats,coef)
importFrom(stats,formula)
importFrom(stats,setNames)
importFrom(utils,capture.output)
importFrom(utils,head)
importFrom(utils,object.size)
importFrom(utils,read.csv)
importFrom(utils,sessionInfo)
importFrom(utils,setTxtProgressBar)
importFrom(utils,str)
importFrom(utils,txtProgressBar)
importFrom(utils,write.csv)
importFrom(yaml,read_yaml)
importFrom(yaml,write_yaml)
